/*
 * Copyright (C) 2012 Giorgio Vazzana
 *
 * This file is part of parole.
 *
 * parole is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * parole is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include <string.h>
#include "oggopus.h"
#include "rw.h"

ogg_packet *make_opus_header0_oggpacket(unsigned char channels, unsigned int samplerate)
{
	int size = 19;
	ogg_packet *op;
	unsigned char *data;

	op   = malloc(sizeof(*op));
	data = malloc(size);
	if (!op || !data)
		return NULL;

	memcpy(data, "OpusHead", 8);     /* identifier */
	data[8] = 1;                     /* version */
	data[9] = channels;              /* channels */
	write_le16(data+10, 0);          /* pre-skip */
	write_le32(data+12, samplerate); /* original sample rate */
	write_le16(data+16, 0);          /* gain */
	data[18] = 0;                    /* channel mapping family */

	op->packet     = data;
	op->bytes      = size;
	op->b_o_s      = 1;
	op->e_o_s      = 0;
	op->granulepos = 0;
	op->packetno   = 0;

	return op;
}

ogg_packet *make_opus_header1_oggpacket(char *vendor)
{
	char *identifier = "OpusTags";
//	char *vendor     = "test";
	int size = strlen(identifier) + 4 + strlen(vendor) + 4;
	ogg_packet *op;
	unsigned char *data;

	op   = malloc(sizeof(*op));
	data = malloc(size);
	if (!op || !data)
		return NULL;

	memcpy(data, identifier, 8);
	write_le32(data+8, strlen(vendor));
	memcpy(data+12, vendor, strlen(vendor));
	write_le32(data+12+strlen(vendor), 0);

	op->packet     = data;
	op->bytes      = size;
	op->b_o_s      = 0;
	op->e_o_s      = 0;
	op->granulepos = 0;
	op->packetno   = 1;

	return op;
}
